@@ -39,9 +39,11 @@ def parse_args():
   worker.add_argument('--dbname', dest='db_name', type=str, default="jobs",  help='mongodb database name (default: jobs)')
   worker.add_argument('--colname', dest='col_name', type=str, default="jobs",  help='mongodb collection name (default: jobs)')
   worker.add_argument('--consumer-id', dest='consumerId', type=str, default=None,  help='worker consumer id (default: None)')
+  worker.add_argument('-l', '--lang', dest='lang', type=str, default="python",  help='worker language (default: python)')
   worker.add_argument('-m', '--modules', dest='modules', action="append", type=str, default=[], help='additional python module paths')
   worker.add_argument('-b', '--heartbeat', dest='heartbeat', type=int, default=1,  help='worker heart beat in seconds (default: 1)')
-  
+  worker.add_argument('-b', '--logger', dest='logger', type=str, default=None,  help='logger callback function (default: None)')
+  worker.add_argument('-v', '--verbosity', dest='verbosity', type=str, default="error",  help='logger verbosity, options are [error, completed, progress] (default: error)')
 
   queue = subparsers.add_parser('queue', description='Schedule a job into the job queue')
   queue.add_argument('function_name', metavar='function_name', type=str, help='the full name of the entry point function')
@@ -50,6 +52,7 @@ def parse_args():
   queue.add_argument('--dbname', dest='db_name', type=str, default="jobs",  help='mongodb database name (default: jobs)')
   queue.add_argument('--colname', dest='col_name', type=str, default="jobs",  help='mongodb collection name (default: jobs)')
   queue.add_argument('--consumer-id', dest='consumerId', type=str, default=None,  help='worker consumer id (default: None)')
+  queue.add_argument('-l', '--lang', dest='lang', type=str, default="python",  help='worker language (default: python)')
   queue.add_argument('-c', '--channel', dest='channel', type=str, default=None, help='channel to place the job (default: None)')
   queue.add_argument('-p', '--priority', dest='priority', type=int, default=None,  help='priority of the job (default: None)')
   queue.add_argument('-j', '--job-id', dest='job_id', type=str, default=None, help='custom id for this job (default: None)')
@@ -88,6 +91,15 @@ def run_worker(args):
   if not args.consumerId is None:
     kwargs['consumerId'] = args.consumerId
 
+  if not args.lang is None:
+    kwargs["lang"] = args.lang
+
+  if not args.logger is None:
+    kwargs['logger'] = args.logger
+
+  if not args.verbosity is None:
+    kwargs['verbosity'] = args.verbosity
+
   if (channels is None) or len(channels) == 0:
     queue = Queue(client, **kwargs)
     queues += (queue,)
@@ -120,10 +132,13 @@ def run_queue(args):
   kwargs = dict(db_name=args.db_name, col_name=args.col_name)
   if not args.consumerId is None:
     kwargs['consumerId'] = args.consumerId
+    
+  if not args.lang is None:
+    kwargs["lang"] = args.lang
 
   queue = Queue(client, **kwargs)
 
-  keys = ['channel', 'priority', 'job_timeout', 'result_ttl', 'ttl', 'failure_ttl', 'depends_on', 'job_id', 'description', 'on_success', 'on_failure', 'max_attempts', 'args', 'kwargs']
+  keys = ['lang', 'channel', 'priority', 'job_timeout', 'result_ttl', 'ttl', 'failure_ttl', 'depends_on', 'job_id', 'description', 'on_success', 'on_failure', 'max_attempts', 'args', 'kwargs']
   params = {}
   for k in keys:
     if hasattr(args, k):
